from django import forms
from crispy_forms.helper import FormHelper
from crispy_forms.layout import Layout, Submit, Row, Column, Button, HTML
from django.db.models import Q
from .models import *
from custom.models import *

class DateInput(forms.DateInput):
	input_type = 'date'

class DateDateField(forms.DateField):
	input_type = 'date'

class ProjectForm(forms.ModelForm):
	obs = forms.CharField(label="Observasaun", widget=forms.Textarea(attrs={"rows":2}), required=False)
	class Meta:
		model = Project
		fields = ['name','company','start_period','end_period','benefit','year','obs']

		widgets = {
		'start_period': DateInput(attrs={'type': 'date'}),
		'end_period': DateInput(attrs={'type': 'date'}),
		}
	def __init__(self, *args, **kwargs):
		super(ProjectForm, self).__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('name', css_class='form-group col-md-6 mb-0'),			
				Column('company', css_class='form-group col-md-6 mb-0'),
			),
			Row(
				Column('start_period', css_class='form-group col-md-6 mb-0'),
				Column('end_period', css_class='form-group col-md-6 mb-0'),
			),
			Row(
				Column('year', css_class='form-group col-md-6 mb-0'),
				Column('benefit', css_class='form-group col-md-6 mb-0'),				
			),
			Row(
				Column('obs', css_class='form-group col-md-12 mb-1'),				
			),
			HTML(""" <div class="text-right mt-4"> <button class="btn btn-sm btn-labeled btn-info" type="submit" title="rai"><span class="btn-label"><i class='fa fa-save'></i></span>Rai</button>"""),
			HTML("""  <button class="btn btn-sm btn-labeled btn-secondary" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</button></div>""")
		)

class ImageProjectForm(forms.ModelForm):
	class Meta:
		model = ImageProject
		fields = ['image']
		widgets = {
		'image':forms.FileInput(attrs={'class':'form-control-file','multiple':True}),
		}

	def __init__(self, *args, **kwargs):
		super(ImageProjectForm, self).__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(			
			Row(
				Column('image', css_class='form-group col-md-12 mb-1'),				
			),
			HTML(""" <div class="text-right mt-4"> <button class="btn btn-sm btn-labeled btn-info" type="submit" title="rai"><span class="btn-label"><i class='fa fa-save'></i></span>Rai</button>"""),
			HTML("""  <button class="btn btn-sm btn-labeled btn-secondary" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</button></div>""")
		)

class ActivityForm(forms.ModelForm):
	obs = forms.CharField(label="Observasaun", widget=forms.Textarea(attrs={"rows":2}), required=False)

	class Meta:
		model = Activity
		fields = ['name','date','place','participation','year',
		'benefit','obs']

		widgets = {
		'date': DateInput(attrs={'type': 'date'}),
		# 'image':forms.FileInput(attrs={'class':'form-control-file','multiple':True})
		}
	def __init__(self, *args, **kwargs):
		super(ActivityForm, self).__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(
			Row(
				Column('name', css_class='form-group col-md-6 mb-0'),			
				Column('date', css_class='form-group col-md-6 mb-0'),
			),
			Row(
				Column('place', css_class='form-group col-md-6 mb-0'),
				Column('participation', css_class='form-group col-md-6 mb-0'),
			),
			Row(
				Column('year', css_class='form-group col-md-6 mb-0'),
				Column('benefit', css_class='form-group col-md-6 mb-0'),
			),
			Row(
				Column('obs', css_class='form-group col-md-12 mb-0'),
			),
			HTML(""" <div class="text-right mt-4"> <button class="btn btn-sm btn-labeled btn-info" type="submit" title="rai"><span class="btn-label"><i class='fa fa-save'></i></span>Rai</button>"""),
			HTML("""  <button class="btn btn-sm btn-labeled btn-secondary" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</button></div>""")
		)

class ImageActivityForm(forms.ModelForm):
	class Meta:
		model = ImageActivity
		fields = ['image']
		widgets = {
		'image':forms.FileInput(attrs={'class':'form-control-file','multiple':True}),
		}

	def __init__(self, *args, **kwargs):
		super(ImageActivityForm, self).__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.layout = Layout(			
			Row(
				Column('image', css_class='form-group col-md-12 mb-1'),				
			),
			HTML(""" <div class="text-right mt-4"> <button class="btn btn-sm btn-labeled btn-info" type="submit" title="rai"><span class="btn-label"><i class='fa fa-save'></i></span>Rai</button>"""),
			HTML("""  <button class="btn btn-sm btn-labeled btn-secondary" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</button></div>""")
		)

class OngForm(forms.ModelForm):
	class Meta:
		model = ONG
		fields = ['name']
class AgencyForm(forms.ModelForm):
	class Meta:
		model = Agency
		fields = ['name']

class NationalForm(forms.ModelForm):
	class Meta:
		model = National
		fields = ['name', 'code']

class FundMunicipalityForm(forms.ModelForm):
	class Meta:
		model = FundMunicipality
		fields = ['municipality', 'municipality_material', 'municipality_amount']

class FundNationalForm(forms.ModelForm):
	class Meta:
		model = FundNational
		fields = ['national', 'national_material', 'national_amount']

class FundONGForm(forms.ModelForm):
	class Meta:
		model = FundONG
		fields = ['ong', 'ong_material', 'ong_amount']

class FundVolunteerForm(forms.ModelForm):
	class Meta:
		model = FundVolunteer
		fields = ['volunteer', 'volunteer_material', 'volunteer_amount']

class FundCommunityContributeForm(forms.ModelForm):
	class Meta:
		model = FundCommunityContribute
		fields = ['community_contribute', 'communitycontribute_material', 'communitycontribute_amount']

class FundAgencyForm(forms.ModelForm):
	class Meta:
		model = FundAgency
		fields = ['agency', 'agency_material', 'agency_amount']

class CompanyForm(forms.ModelForm):
	class Meta:
		model = Company
		fields = ['name']



from django.shortcuts import render, redirect, resolve_url, HttpResponse, get_object_or_404
from development.forms import ProjectForm
from development.models import *
from django.contrib.auth.decorators import login_required
from django.contrib.auth.models import User
from custom.models import *
import numpy as np
import pandas as pd
from django.db.models import Q
from custom.utils import getnewid, getjustnewid, hash_md5, getlastid
from django.db.models import Avg, Count, Min, Sum
# report
from io import BytesIO
from django.template.loader import get_template
from xhtml2pdf import pisa

from employee.models import *


@login_required
def ReportList(request):
    year = Year.objects.all()
    empuser = None
    employee = None
    # EmployeeUser.objects.get(user = request.user).exists():
    try:
        empuser = EmployeeUser.objects.get(user = request.user)
        employee = Employee.objects.get(employeeuser=empuser)
    except:
        print('You are admin')
    if request.method == 'POST':
        developmentReport = request.POST.get('developmentReport')
        year = request.POST.get('year')
        if developmentReport == "C1":
            # print(year)
            project = Project.objects.filter(year__year=year,municipality=employee.municipality, administrativepost=employee.administrativepost, village=employee.village)
            fNational = FundNational.objects.all()
            fMunicipality = FundMunicipality.objects.all()
            fOng = FundONG.objects.all()
            fVolunteer = FundVolunteer.objects.all()
            total = []
            for pro in project:
                fn,fm,fo,fv,total_fund =   [],[],[],[], []
                fn = FundNational.objects.filter(project=pro.id).aggregate(Sum('national_amount'))
                fm = FundMunicipality.objects.filter(project=pro.id).aggregate(Sum('municipality_amount'))
                fo = FundONG.objects.filter(project=pro.id).aggregate(Sum('ong_amount'))
                fv = FundVolunteer.objects.filter(project=pro.id).aggregate(Sum('volunteer_amount'))
                if fn['national_amount__sum']:
                    total_fund.append(fn['national_amount__sum'])
                if fm['municipality_amount__sum']:
                    total_fund.append(fm['municipality_amount__sum'])
                if fo['ong_amount__sum']:
                    total_fund.append(fo['ong_amount__sum'])
                if fv['volunteer_amount__sum']:
                    total_fund.append(fv['volunteer_amount__sum'])
                total.append(np.sum(total_fund))
            df1 = pd.DataFrame(project)
            df1['total_amount'] = total
    
            data = {
                'title': 'Relatóriu Projetu', 
                'objects': df1, 'employee': employee,
                'fNational': fNational, 'fMunicipality': fMunicipality, 'fOng':fOng, 'fVolunteer':fVolunteer,
                'total_amount_national':total,'year':year
            }
            if 'print' in request.POST:
                data["page"] = "print"
                return render(request, 'reports/print/project.html', data)
            elif 'excel' in request.POST:
                data["page"] = "excel"
                return render(request, 'reports/print/project.html', data)

        if developmentReport == "C2":
            activity = Activity.objects.filter(year__year=year,municipality=employee.municipality, administrativepost=employee.administrativepost, village=employee.village)
            fNational = FundNational.objects.all()
            fMunicipality = FundMunicipality.objects.all()
            fCommunity = FundCommunityContribute.objects.all()
            fAgency = FundAgency.objects.all()
            total = []
            for ac in activity:
                fn,fm,fc,fa,total_fund =   [],[],[],[], []
                fn = FundNational.objects.filter(activity=ac.id).aggregate(Sum('national_amount'))
                fm = FundMunicipality.objects.filter(activity=ac.id).aggregate(Sum('municipality_amount'))
                fc = FundCommunityContribute.objects.filter(activity=ac.id).aggregate(Sum('communitycontribute_amount'))
                fa = FundAgency.objects.filter(activity=ac.id).aggregate(Sum('agency_amount'))
                if fn['national_amount__sum']:
                    total_fund.append(fn['national_amount__sum'])
                if fm['municipality_amount__sum']:
                    total_fund.append(fm['municipality_amount__sum'])
                if fc['communitycontribute_amount__sum']:
                    total_fund.append(fc['communitycontribute_amount__sum'])
                if fa['agency_amount__sum']:
                    total_fund.append(fa['agency_amount__sum'])
                total.append(np.sum(total_fund))
            df1 = pd.DataFrame(activity)
            df1['total_amount'] = total
    
            data = {
                'title': 'Relatóriu Atividade', 
                'objects': df1, 'employee': employee,
                'fNational': fNational, 'fMunicipality': fMunicipality, 'fCommunity':fCommunity, 'fAgency':fAgency,
                'total_amount_national':total,'year':year
            }
            if 'print' in request.POST:
                data["page"] = "print"
                return render(request, 'reports/print/activity.html', data)
            elif 'excel' in request.POST:
                data["page"] = "excel"
                return render(request, 'reports/print/activity.html', data)

    context = {'year':year,'title':"Livru Relatóriu Sira", 'report':"active"}
    return render(request, 'reports/report_dashboard.html', context)







from django.shortcuts import render, redirect
from django.contrib import messages
from development.forms import FundMunicipalityForm, FundNationalForm,FundONGForm,FundVolunteerForm, FundCommunityContributeForm,FundAgencyForm
from custom.utils import getnewid, getjustnewid, hash_md5, getlastid
from django.contrib.auth.decorators import login_required
from custom.models import *
from development.models import *
from employee.models import *
from django.contrib.auth.models import User

@login_required
def FundNationalList(request):
	national = FundNational.objects.filter(user_id=request.user.id)
	context ={'title':'Fundus Nasional', 'fundnational':"active", 'page':"National",'national':national}
	return render(request, 'fund/fundlist.html', context)

@login_required
def FundMunicipalityList(request):
	municipality = FundMunicipality.objects.filter(user_id=request.user.id)
	context ={'title':'Fundus Munisípiu',
	'fundmunicipality':"active", 'page':"Municipality",'municipality':municipality}
	return render(request, 'fund/fundlist.html', context)

@login_required
def FundONGList(request):
	ong = FundONG.objects.filter(user_id=request.user.id)
	context ={'title':'Fundus ONG', 'fundong':"active", 'page':"ONG",'ong':ong}
	return render(request, 'fund/fundlist.html', context)

@login_required
def FundAgencyList(request):
	agency = FundAgency.objects.filter(user_id=request.user.id)
	context ={'title':'Fundus ONG', 'fundagency':"active", 'page':"Agency",'agency':agency}
	return render(request, 'fund/fundlist.html', context)

@login_required
def FundProjectAdd(request, hashed):
	project = Project.objects.get(hashed=hashed)
	form = FundMunicipalityForm()
	form1 = FundNationalForm()
	form2 = FundONGForm()
	form3 = FundVolunteerForm()

	if request.method == 'POST':
		if request.POST['municipality_amount']:
			newid = getjustnewid(FundMunicipality)

			form = FundMunicipalityForm(request.POST)
			if form.is_valid():
				instance = form.save(commit=False)
				instance.id = newid
				instance.project_id = project.id
				instance.user = request.user
				instance.save()

		if request.POST['national_amount']:
			newid1 = getjustnewid(FundNational)

			form1 = FundNationalForm(request.POST)
			if form1.is_valid():
				instance = form1.save(commit=False)
				instance.id = newid1
				instance.project_id = project.id
				instance.user = request.user
				instance.save()

		if request.POST['ong_amount']:
			newid2 = getjustnewid(FundONG)

			form2 = FundONGForm(request.POST)
			if form2.is_valid():
				instance = form2.save(commit=False)
				instance.id = newid2
				instance.project_id = project.id
				instance.user = request.user
				instance.save()

		if request.POST['volunteer_amount']:
			newid3 = getjustnewid(Project)

			form3 = FundVolunteerForm(request.POST)
			if form3.is_valid():
				instance = form3.save(commit=False)
				instance.id = newid3
				instance.project_id = project.id
				instance.user = request.user
				instance.save()
		messages.success(request, f'Susesu Kria Fundus ba Projetu' )
		return redirect('development:project-add-image', project.hashed)

	context = {'title':'Adisiona Fundus Projetu', 'project1':"active", 'page':"addproject", 'project':project, 'form':form,'form1':form1,'form2':form2,'form3':form3}
	return render(request, 'fund/fundprojectadd.html', context)

@login_required
def FundProjectAdd1(request, hashed):
	project = Project.objects.get(hashed=hashed)
	form = FundMunicipalityForm()
	form1 = FundNationalForm()
	form2 = FundONGForm()
	form3 = FundVolunteerForm()

	if request.method == 'POST':
		if request.POST['municipality_amount']:
			newid = getjustnewid(FundMunicipality)

			form = FundMunicipalityForm(request.POST)
			if form.is_valid():
				instance = form.save(commit=False)
				instance.id = newid
				instance.project_id = project.id
				instance.user = request.user
				instance.save()

		if request.POST['national_amount']:
			newid1 = getjustnewid(FundNational)

			form1 = FundNationalForm(request.POST)
			if form1.is_valid():
				instance = form1.save(commit=False)
				instance.id = newid1
				instance.project_id = project.id
				instance.user = request.user
				instance.save()

		if request.POST['ong_amount']:
			newid2 = getjustnewid(FundONG)

			form2 = FundONGForm(request.POST)
			if form2.is_valid():
				instance = form2.save(commit=False)
				instance.id = newid2
				instance.project_id = project.id
				instance.user = request.user
				instance.save()

		if request.POST['volunteer_amount']:
			newid3 = getjustnewid(Project)

			form3 = FundVolunteerForm(request.POST)
			if form3.is_valid():
				instance = form3.save(commit=False)
				instance.id = newid3
				instance.project_id = project.id
				instance.user = request.user
				instance.save()
		messages.success(request, f'Susesu Kria Fundus ba Projetu' )
		return redirect('development:project-viewdetail', project.hashed)

	context = {'title':'Adisiona Fundus Projetu', 'project1':"active", 'page':"addproject", 'project':project, 'form':form,'form1':form1,'form2':form2,'form3':form3}
	return render(request, 'fund/fundprojectadd.html', context)

@login_required
def FundNationalEdit(request, hashed):
	fundnational = FundNational.objects.get(hashed=hashed)
	project = fundnational.project
	page = 'editprojectfundnational'
	if fundnational.activity:
		page ='editactivityfundnational'
		project = fundnational.activity
	# page = 'editprojectfundnational'
	form = FundNationalForm(instance=fundnational)
	if request.method == 'POST':
		form = FundNationalForm(request.POST, instance=fundnational)
		if form.is_valid():
			form.save()
			if fundnational.activity == None:
				messages.success(request, f'Susesu Altera Fundus Husi Nasional ba Projetu' )
				return redirect('development:project-viewdetail', fundnational.project.hashed)
			else:
				messages.success(request, f'Susesu Altera Fundus Husi Nasional ba Atividade' )
				return redirect('development:activity-detail', fundnational.activity.hashed)

	context = {'title':'Altera Fundus Husi Nasional', 'page':page, 'project':project, 'form':form}
	return render(request, 'fund/fundprojectadd.html', context)

@login_required
def FundMunicipalityEdit(request, hashed):
	fundmunicipality = FundMunicipality.objects.get(hashed=hashed)
	project = fundmunicipality.project
	page = 'editprojectfundmunicipality'
	if fundmunicipality.activity:
		page ='editactivityfundmunicipality'
		project = fundmunicipality.activity
	
	# print(fundmunicipality.activity)
	form = FundMunicipalityForm(instance=fundmunicipality)
	if request.method == 'POST':
		form = FundMunicipalityForm(request.POST, instance=fundmunicipality)
		if form.is_valid():
			form.save()
			if fundmunicipality.activity == None:
				messages.success(request, f'Susesu Altera Fundus Husi Munisípiu ba Projetu')
				return redirect('development:project-viewdetail', fundmunicipality.project.hashed)
			else:
				messages.success(request, f'Susesu Altera Fundus Husi Munisípiu ba Atividade')
				return redirect('development:activity-detail', fundmunicipality.activity.hashed)

	context = {'title':'Altera Fundus Husi Munisípiu', 'page':page, 'project':project, 'form':form}
	return render(request, 'fund/fundprojectadd.html', context)

def FundONGEdit(request, hashed):
	fundong = FundONG.objects.get(hashed=hashed)
	project = fundong.project
	page = 'editprojectong'
	form = FundONGForm(instance=fundong)
	if request.method == 'POST':
		form = FundONGForm(request.POST, instance=fundong)
		if form.is_valid():
			form.save()
			messages.success(request, f'Susesu Altera Fundus Husi ONG ba Projetu')
			return redirect('development:project-viewdetail', fundong.project.hashed)

	context = {'title':'Altera Fundus Husi ONG ba Projetu', 'page':page, 'project':project,'form':form}
	return render(request, 'fund/fundprojectadd.html', context)

@login_required
def FundVolunteerEdit(request, hashed):
	fundvolunteer = FundVolunteer.objects.get(hashed=hashed)
	project = fundvolunteer.project
	page = 'editprojecvolunteer'
	form = FundVolunteerForm(instance=fundvolunteer)
	if request.method == 'POST':
		form = FundVolunteerForm(request.POST, instance=fundvolunteer)
		if form.is_valid():
			form.save()
			messages.success(request, f'Susesu Altera Fundus Husi Volutariu ba Projetu')
			return redirect('development:project-viewdetail', fundvolunteer.project.hashed)

	context = {'title':'Altera Fundus Husi Voluntariu ba Projetu', 'project':project, 'page':page, 'form':form}
	return render(request, 'fund/fundprojectadd.html', context)

@login_required
def FundActivityAdd(request, hashed):
	activity = Activity.objects.get(hashed=hashed)
	form = FundCommunityContributeForm()
	form1 = FundMunicipalityForm()
	form2 = FundNationalForm()
	form3 = FundAgencyForm()

	if request.method == 'POST':
		if request.POST['communitycontribute_amount']:
			newid = getjustnewid(FundCommunityContribute)

			form = FundCommunityContributeForm(request.POST)
			if form.is_valid():
				instance = form.save(commit=False)
				instance.id = newid
				instance.activity_id = activity.id
				instance.user = request.user
				instance.save()

		if request.POST['municipality_amount']:
			newid1 = getjustnewid(FundMunicipality)

			form1 = FundMunicipalityForm(request.POST)
			if form1.is_valid():
				instance = form1.save(commit=False)
				instance.id = newid1
				instance.activity_id = activity.id
				instance.user = request.user
				instance.save()

		if request.POST['national_amount']:
			newid2 = getjustnewid(FundNational)

			form2 = FundNationalForm(request.POST)
			if form2.is_valid():
				instance = form2.save(commit=False)
				instance.id = newid2
				instance.activity_id = activity.id
				instance.user = request.user
				instance.save()

		if request.POST['agency_amount']:
			newid3 = getjustnewid(FundAgency)

			form3 = FundAgencyForm(request.POST)
			if form3.is_valid():
				instance = form3.save(commit=False)
				instance.id = newid3
				instance.activity_id = activity.id
				instance.user = request.user
				instance.save()
		messages.success(request, f'Susesu Kria Fundus ba Atividade' )
		return redirect('development:activity-add-image', activity.hashed)
	context = {'title':'Adisiona Fundus Atividade', 'activity1':"active", 'page':"addactivity", 'activity':activity, 'form':form,'form1':form1,'form2':form2,'form3':form3}
	return render(request, 'fund/fundactivityadd.html', context)

@login_required
def FundActivityAdd1(request, hashed):
	activity = Activity.objects.get(hashed=hashed)
	form = FundCommunityContributeForm()
	form1 = FundMunicipalityForm()
	form2 = FundNationalForm()
	form3 = FundAgencyForm()

	if request.method == 'POST':
		if request.POST['communitycontribute_amount']:
			newid = getjustnewid(FundCommunityContribute)

			form = FundCommunityContributeForm(request.POST)
			if form.is_valid():
				instance = form.save(commit=False)
				instance.id = newid
				instance.activity_id = activity.id
				instance.user = request.user
				instance.save()

		if request.POST['municipality_amount']:
			newid1 = getjustnewid(FundMunicipality)

			form1 = FundMunicipalityForm(request.POST)
			if form1.is_valid():
				instance = form1.save(commit=False)
				instance.id = newid1
				instance.activity_id = activity.id
				instance.user = request.user
				instance.save()

		if request.POST['national_amount']:
			newid2 = getjustnewid(FundNational)

			form2 = FundNationalForm(request.POST)
			if form2.is_valid():
				instance = form2.save(commit=False)
				instance.id = newid2
				instance.activity_id = activity.id
				instance.user = request.user
				instance.save()

		if request.POST['agency_amount']:
			newid3 = getjustnewid(FundAgency)

			form3 = FundAgencyForm(request.POST)
			if form3.is_valid():
				instance = form3.save(commit=False)
				instance.id = newid3
				instance.activity_id = activity.id
				instance.user = request.user
				instance.save()
		messages.success(request, f'Susesu Kria Fundus ba Atividade' )
		return redirect('development:activity-detail', activity.hashed)
	context = {'title':'Adisiona Fundus Atividade', 'activity1':"active", 'page':"addactivity", 'activity':activity, 'form':form,'form1':form1,'form2':form2,'form3':form3}
	return render(request, 'fund/fundactivityadd.html', context)

@login_required
def FundAgencyEdit(request, hashed):
	fundagency = FundAgency.objects.get(hashed=hashed)
	activity = fundagency.activity
	form = FundAgencyForm(instance=fundagency)
	if request.method == 'POST':
		form = FundAgencyForm(request.POST, instance=fundagency)
		if form.is_valid():
			form.save()
			messages.success(request, f'Susesu Altera Fundus Husi Ajensia ba Atividade')
			return redirect('development:activity-detail', fundagency.activity.hashed)

	context = {'title':'Altera fundus Atividade Husi Ajensia','activity': activity, 'page':"editactivityagency", 'form':form}
	return render(request, 'fund/fundactivityadd.html', context)

@login_required
def FundCommunityContributeEdit(request, hashed):
	fundcommunitycontribute = FundCommunityContribute.objects.get(hashed=hashed)
	activity = fundcommunitycontribute.activity
	form = FundCommunityContributeForm(instance=fundcommunitycontribute)
	if request.method == 'POST':
		form = FundCommunityContributeForm(request.POST, instance=fundcommunitycontribute)
		if form.is_valid():
			form.save()
			messages.success(request, f'Susesu Altera Fundus Husi Kontribuisaun Komunidade ba Projetu')
			return redirect('development:activity-detail', fundcommunitycontribute.activity.hashed)

	context = {'title':'Altera fundus Atividade Husi Komunidade', 'activity': activity, 'page':"editactivitycommunity", 'form':form}
	return render(request, 'fund/fundactivityadd.html', context)







from django.db import models
import hashlib
from django.contrib.auth.models import User
from custom.models import *
from custom_development.models import * 
from django.core.validators import FileExtensionValidator


	
class Project(models.Model):
	name = models.CharField(max_length=300, verbose_name='Naran Projetu', null=True)
	company = models.ForeignKey(Company, on_delete=models.CASCADE, verbose_name="Naran Kompañia", null=True)
	start_period = models.DateField(auto_now_add=False, verbose_name='Data Hahu', null=True)
	end_period = models.DateField(auto_now_add=False, verbose_name='Data Remata', null=True)
	benefit = models.CharField(max_length=200, verbose_name='Benefísiu', null=True)
	obs = models.TextField(verbose_name="OBS")
	year = models.ForeignKey(Year, on_delete=models.CASCADE, blank=True, null=True, verbose_name="Tinan")
	municipality = models.ForeignKey(Municipality, on_delete=models.CASCADE, blank=True, null=True)
	administrativepost = models.ForeignKey(AdministrativePost, on_delete=models.CASCADE, blank=True, null=True)
	village = models.ForeignKey(Village, on_delete=models.CASCADE, blank=True, null=True)	
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, verbose_name="Author")
	hashed = models.CharField(max_length=50, null=True, blank=True)
	datetime = models.DateTimeField(auto_now_add=True, null=True)
	def __str__(self):
		template = '{0.name}'
		return template.format(self)

	def save(self, *args, **kwargs):
		self.hashed = hashlib.md5(str(self.id).encode()).hexdigest()
		return super(Project, self).save(*args, **kwargs)

	class Meta:
		verbose_name_plural='C.1. Livru Dadus Projetu Suku'

class ImageProject(models.Model):
	project = models.ForeignKey(Project, on_delete=models.CASCADE, verbose_name='Naran Projetu', null=True)
	image = models.FileField(upload_to='development/project/', null=True, blank=True,
			validators=[FileExtensionValidator(allowed_extensions=['jpg','jpeg','png'])], verbose_name="Aneksu Imajen")
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True)
	datetime = models.DateTimeField(null=True)

	def __str__(self):
		template = '{0.project}'
		return template.format(self)

	class Meta:
		verbose_name_plural='Aneksu Imajen Projetu'	

class FundONG(models.Model):
	ong = models.ForeignKey(ONG, on_delete=models.CASCADE, verbose_name="ONG", null=True, blank=True)
	ong_material = models.CharField(max_length=50, null=True, blank=True, verbose_name="Ajuda Material")
	ong_amount = models.DecimalField(max_digits=11, decimal_places=2, null=True, blank=True, verbose_name='Total Osan')
	project = models.ForeignKey(Project, on_delete=models.CASCADE, verbose_name="Naran Projetu", null=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, verbose_name="Author")
	hashed = models.CharField(max_length=50, null=True, blank=True)

	def __str__(self):
		template = '{0.ong}'
		return template.format(self)

	def save(self, *args, **kwargs):
		self.hashed = hashlib.md5(str(self.id).encode()).hexdigest()
		return super(FundONG, self).save(*args, **kwargs)

	class Meta:
		verbose_name_plural='Fundus Husi ONG'

class FundVolunteer(models.Model):
	volunteer = models.CharField(max_length=200, verbose_name='Voluntáriu', null=True, blank=True)
	volunteer_material = models.CharField(max_length=50, null=True, blank=True, verbose_name="Ajuda Material")
	volunteer_amount = models.DecimalField(max_digits=11, decimal_places=2, verbose_name='Total Osan', null=True, blank=True)
	project = models.ForeignKey(Project, on_delete=models.CASCADE, verbose_name='Naran Projetu', null=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, verbose_name="Author")
	hashed = models.CharField(max_length=50, null=True, blank=True)

	def __str__(self):
		template = '{0.volunteer}'
		return template.format(self)
	def save(self, *args, **kwargs):
		self.hashed = hashlib.md5(str(self.id).encode()).hexdigest()
		return super(FundVolunteer, self).save(*args, **kwargs)

	class Meta:
		verbose_name_plural='Fundus Husi Voluntáriu'

class Activity(models.Model):
	date = models.DateField(auto_now_add=False, verbose_name='Data Atividade', null=True)
	name = models.CharField(max_length=300, verbose_name="Naran Atividade", blank=True)
	place = models.CharField(max_length=250, verbose_name='Fatin', blank=True)	
	participation = models.CharField(max_length=255, verbose_name="Partisipasaun", null=True)
	benefit = models.CharField(max_length=250, verbose_name="Benefísiu", null=True)
	obs = models.TextField(verbose_name="OBS")
	year = models.ForeignKey(Year, on_delete=models.CASCADE, blank=True, null=True, verbose_name="Tinan")
	municipality = models.ForeignKey(Municipality, on_delete=models.CASCADE, blank=True, null=True)
	administrativepost = models.ForeignKey(AdministrativePost, on_delete=models.CASCADE, blank=True, null=True)
	village = models.ForeignKey(Village, on_delete=models.CASCADE, blank=True, null=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, verbose_name="Author")
	hashed = models.CharField(max_length=50, null=True, blank=True)
	datetime = models.DateTimeField(auto_now_add=True, null=True)
	def __str__(self):
		template = '{0.name}'
		return template.format(self)

	def save(self, *args, **kwargs):
		self.hashed = hashlib.md5(str(self.id).encode()).hexdigest()
		return super(Activity, self).save(*args, **kwargs)

	class Meta:
		verbose_name_plural='C.2. Livru Dadus Atividade Suku'

class ImageActivity(models.Model):
	activity = models.ForeignKey(Activity, on_delete=models.CASCADE, null=True, related_name="activityfiles", verbose_name="Naran Atividade")
	image = models.FileField(upload_to='development/activity/', null=True, blank=True,
			validators=[FileExtensionValidator(allowed_extensions=['jpg','jpeg','png'])], verbose_name="Aneksu Imajen")
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True)
	datetime = models.DateTimeField(null=True)

	def __str__(self):
		template = '{0.activity}'
		return template.format(self)
	
	class Meta:
		verbose_name_plural='Aneksu Imajen Atividade'


class FundCommunityContribute(models.Model):
	community_contribute = models.CharField(max_length=200, verbose_name='Kontribuisaun Komunidade', null=True, blank=True)
	communitycontribute_material = models.CharField(max_length=50, null=True, blank=True, verbose_name="Ajuda Material")
	communitycontribute_amount = models.DecimalField(max_digits=11, decimal_places=2, null=True, blank=True, verbose_name='Total Osan')
	activity = models.ForeignKey(Activity, on_delete=models.CASCADE, verbose_name='Naran Atividade', null=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, verbose_name="Author")
	hashed = models.CharField(max_length=50, null=True, blank=True)

	def __str__(self):
		template = '{0.community_contribute}'
		return template.format(self)

	def save(self, *args, **kwargs):
		self.hashed = hashlib.md5(str(self.id).encode()).hexdigest()
		return super(FundCommunityContribute, self).save(*args, **kwargs)
	class Meta:
		verbose_name_plural='Fundus Husi Kontribuisaun Komunidade'

class FundAgency(models.Model):
	agency = models.ForeignKey(Agency, on_delete=models.CASCADE, verbose_name='Ajénsia', null=True, blank=True)
	agency_material = models.CharField(max_length=50, null=True, blank=True, verbose_name="Ajuda Material")
	agency_amount = models.DecimalField(max_digits=11, decimal_places=2, null=True, blank=True, verbose_name='Total Osan')
	activity = models.ForeignKey(Activity, on_delete=models.CASCADE, verbose_name='Naran Projetu', null=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, verbose_name="Author")
	hashed = models.CharField(max_length=32, null=True, blank=True)

	def __str__(self):
		template = '{0.agency}'
		return template.format(self)

	def save(self, *args, **kwargs):
		self.hashed = hashlib.md5(str(self.id).encode()).hexdigest()
		return super(FundAgency, self).save(*args, **kwargs)
	class Meta:
		verbose_name_plural='Fundus Husi Ajénsia'


class FundMunicipality(models.Model):
	municipality = models.ForeignKey(Municipality, on_delete=models.CASCADE, verbose_name="Munisípiu", null=True, blank=True)
	municipality_material = models.CharField(max_length=50, null=True, blank=True, verbose_name="Ajuda Material")
	municipality_amount = models.DecimalField(max_digits=11, decimal_places=2, null=True, blank=True, verbose_name='Total Osan')
	project = models.ForeignKey(Project, on_delete=models.CASCADE, verbose_name="Naran Projetu", null=True, blank=True)
	activity = models.ForeignKey(Activity, on_delete=models.CASCADE, verbose_name="Naran Atividade", null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, verbose_name="Author")
	hashed = models.CharField(max_length=50, null=True, blank=True)

	def __str__(self):
		template = '{0.municipality}'
		return template.format(self)

	def save(self, *args, **kwargs):
		self.hashed = hashlib.md5(str(self.id).encode()).hexdigest()
		return super(FundMunicipality, self).save(*args, **kwargs)
	class Meta:
		verbose_name_plural='Fundus Husi Munisípiu'

class FundNational(models.Model):
	national = models.ForeignKey(National, on_delete=models.CASCADE, verbose_name="Nasional", null=True, blank=True)
	national_material = models.CharField(max_length=50, null=True, blank=True, verbose_name="Ajuda Material")
	national_amount = models.DecimalField(max_digits=11, decimal_places=2, null=True, blank=True, verbose_name='Total Osan')
	project = models.ForeignKey(Project, on_delete=models.CASCADE, verbose_name="Naran Projetu", null=True, blank=True)
	activity = models.ForeignKey(Activity, on_delete=models.CASCADE, verbose_name="Naran Atividade", null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, verbose_name="Author")
	hashed = models.CharField(max_length=50, null=True, blank=True)


	def __str__(self):
		template = '{0.national}'
		return template.format(self)

	def save(self, *args, **kwargs):
		self.hashed = hashlib.md5(str(self.id).encode()).hexdigest()
		return super(FundNational, self).save(*args, **kwargs)

	class Meta:
		verbose_name_plural='Fundus Husi Nasional'


from django.shortcuts import render, redirect, get_object_or_404
from development.forms import ProjectForm, ImageProjectForm
from django.http import JsonResponse
from django.contrib import messages
from development.models import *
from custom.utils import getnewid, getjustnewid, hash_md5, getlastid
from django.db.models import Count
from xhtml2pdf import pisa
from django.db.models import Q
from django.contrib.auth.decorators import login_required
from datetime import date
import numpy as np
from administration.models import Year
from main.decorators import allowed_users
from employee.models import *
# ===================charts===================
def convertMonthNumberToText(number):
	if number == 1:
		return "Janeiru"
	elif number == 2:
		return "Fevreiru"
	elif number == 3:
		return "Marsu"
	elif number == 4:
		return "Abril"
	elif number == 5:
		return "Maiu"
	elif number == 6:
		return "Junhu"
	elif number == 7:
		return "Julhu"
	elif number == 8:
		return "Augustu"
	elif number == 9:
		return "Setembru"
	elif number == 10:
		return "Outubru"
	elif number == 11:
		return "Novembru"
	elif number == 12:
		return "Dezembru"
	
# Create your views here.


@login_required
def DevelopmentDashboard(request):
	try:
		empuser = EmployeeUser.objects.get(user = request.user)
		employee = Employee.objects.get(employeeuser=empuser)
	except:
		print('You are admin')
	countproject = Project.objects.filter(municipality=employee.municipality, administrativepost=employee.administrativepost, village=employee.village).count()
	countactivity = Activity.objects.filter(municipality=employee.municipality, administrativepost=employee.administrativepost, village=employee.village).count()

	context = {'title': 'Painel Dezenvolvimentu', 'employee':employee, 'development':"active",
	'countproject':countproject,'countactivity':countactivity}
	return render(request, 'development/dashboard_development.html', context)

@login_required
def project_charts(request):
	# currentYear = date.today().year
	try:
		empuser = EmployeeUser.objects.get(user = request.user)
		employee = Employee.objects.get(employeeuser=empuser)
	except:
		print('You are admin')
	labels = []
	data = []
	# currentYear2 = get_object_or_404(Year,year=currentYear)
	querysets = Project.objects.filter(municipality=employee.municipality, administrativepost=employee.administrativepost, village=employee.village)\
	.values('year__year').annotate(count=Count('id'))
	for entry in querysets:
		# month = convertMonthNumberToText(entry['datetime__year'])
		labels.append(entry['year__year'])
		data.append(entry['count'])
	# print(data)
	return JsonResponse(data={
		'labels':labels,
		'data':data,
		})

@login_required
def activity_charts(request):
	currentYear = date.today().year
	try:
		empuser = EmployeeUser.objects.get(user = request.user)
		employee = Employee.objects.get(employeeuser=empuser)
	except:
		print('You are admin')
	labels = []
	data = []
	# currentYear2 = get_object_or_404(Year,year=currentYear)
	querysets = Activity.objects.filter(municipality=employee.municipality, administrativepost=employee.administrativepost, village=employee.village)\
	.values('year__year').annotate(count=Count('id'))
	for entry in querysets:
		# month = convertMonthNumberToText(entry['date__month'])
		labels.append(entry['year__year'])
		data.append(entry['count'])
	# print(data)
	return JsonResponse(data={
		'labels':labels,
		'data':data,
		})

@login_required
def ProjectList(request):
	group = request.user.groups.all()[0].name
	try:
		empuser = EmployeeUser.objects.get(user = request.user)
		employee = Employee.objects.get(employeeuser=empuser)
	except:
		print('You are admin')
	objects = Project.objects.filter(municipality=employee.municipality, administrativepost=employee.administrativepost, village=employee.village)
	context = {
		'title': 'Lista Projetu','page':"view", 'group': group,
		'objects': objects,'project1':"active"
	}
	return render(request,'project/list.html', context)

@login_required
def ProjectDetail(request, hashed):
	group = request.user.groups.all()[0].name
	objects = Project.objects.get(hashed=hashed)
	imageproject = ImageProject.objects.filter(project=objects)
	fundNational = FundNational.objects.filter(project=objects)
	fundMunicipality = FundMunicipality.objects.filter(project=objects)
	fundOng = FundONG.objects.filter(project=objects)
	fundVolunteer = FundVolunteer.objects.filter(project=objects)
	data = []
	for i in fundNational:
		data.append({'fund': 'Nasional', 'name': i, 'hashed': i.hashed, 'amount': i.national_amount, 'material': i.national_material})
	for j in fundMunicipality:
		data.append({'fund': 'Munisípiu', 'name': j, 'hashed': j.hashed, 'amount': j.municipality_amount, 'material': j.municipality_material})
	for k in fundOng:
		data.append({'fund': 'ONG', 'name': k, 'hashed': k.hashed, 'amount': k.ong_amount, 'material': k.ong_material})
	for l in fundVolunteer:
		data.append({'fund': 'Voluntáriu', 'name': l, 'hashed': l.hashed, 'amount': l.volunteer_amount, 'material': l.volunteer_material})
	result = np.array(data)
	total = []
	for r  in result:
		total.append(r['amount'])
	total_amount = np.sum(total)
	context =  {
		'objects':objects,'title': 'Detalla Projetu', 'project1':"active",'group': group,
		'result': result, 'total': total_amount, 'fundNational':fundNational,
		'imageproject':imageproject
	}
	return render(request, 'project/detail.html', context)


@login_required
@allowed_users(['sec', 'admin', 'xefe'])
def ProjectAdd(request):
	municipality = Municipality.objects.all()
	if request.method == 'POST':
		newid = getjustnewid(Project)

		form = ProjectForm(request.POST, request.FILES)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.id = newid
			instance.user = request.user
			user = get_object_or_404(EmployeeUser,user__id=request.user.id)
			instance.municipality = user.employee.municipality
			instance.administrativepost = user.employee.administrativepost
			instance.village = user.employee.village
			instance.save()
			messages.success(request, f'Susesu Kria Projetu!' )
			return redirect('development:project-add-fund', instance.hashed)
	else:
		form = ProjectForm()	
	context = {'form':form, 'municipality':municipality, 'project1':"active",
	'title':'Adisiona Projetu'}
	return render(request, 'project/add.html', context)

@login_required
@allowed_users(['sec', 'admin', 'xefe'])
def ImageProjectAdd(request, hashed):
	project = get_object_or_404(Project, hashed=hashed)
	if request.method == 'POST':
		newid = getjustnewid(ImageProject)
		images = request.FILES.getlist('image')

		form = ImageProjectForm(request.POST, request.FILES)
		if form.is_valid():
			for f in images:
				files = ImageProject(project_id=project.id, image=f,user=request.user)
				files.save()
			messages.success(request, f'Susesu Kria Aneksu Imajen!' )
			return redirect('development:project-viewdetail', project.hashed)
	else:
		form = ImageProjectForm()	
	context = {'form':form, 'project1':"active",
	'title':'Aneksu Imajen ba Projetu %s' % (project.name)}
	return render(request, 'project/add1.html', context)

@login_required
@allowed_users(['sec'])
def ProjectEdit(request, hashed):
	project = Project.objects.get(hashed=hashed)

	form = ProjectForm(instance=project)
	if request.method == 'POST':
		form = ProjectForm(request.POST, instance=project)
		if form.is_valid():
			form.save()
			messages.success(request, f'Susesu Altera Projetu' )
			return redirect('development:project-list')

	context = {'title':'Altera Projetu','form':form, 'page': 'altera','project1':"active"}
	return render(request, 'project/add.html', context)

@login_required
@allowed_users(allowed_roles=['sec', 'xefe'])
def DeleteProject(request, hashed):
	project = get_object_or_404(Project,hashed=hashed)
	project.delete()
	messages.success(request, f'Dadus projetu {project.name} Hamoos ho Susesu.')
	return redirect('development:project-list')



from django.contrib import admin
from development.models import *

# Register your models here.
admin.site.register(ImageProject)
admin.site.register(ImageActivity)

from import_export import resources

from import_export.admin import ImportExportModelAdmin



class ProjectResource(resources.ModelResource):
    class Meta:
        model = Project
class ProjectAdmin(ImportExportModelAdmin):
    resource_class = ProjectResource
admin.site.register(Project, ProjectAdmin)


class ActivityResource(resources.ModelResource):
    class Meta:
        model = Activity
class ActivityAdmin(ImportExportModelAdmin):
    resource_class = ActivityResource
admin.site.register(Activity, ActivityAdmin)


class FundAgencyResource(resources.ModelResource):
    class Meta:
        model = FundAgency
class FundAgencyAdmin(ImportExportModelAdmin):
    resource_class = FundAgencyResource
admin.site.register(FundAgency, FundAgencyAdmin)



class FundCommunityContributeResource(resources.ModelResource):
    class Meta:
        model = FundCommunityContribute
class FundCommunityContributeAdmin(ImportExportModelAdmin):
    resource_class = FundCommunityContributeResource
admin.site.register(FundCommunityContribute, FundCommunityContributeAdmin)


class FundNationalResource(resources.ModelResource):
    class Meta:
        model = FundNational
class FundNationalAdmin(ImportExportModelAdmin):
    resource_class = FundNationalResource
admin.site.register(FundNational, FundNationalAdmin)



class FundMunicipalityResource(resources.ModelResource):
    class Meta:
        model = FundMunicipality
class FundMunicipalityAdmin(ImportExportModelAdmin):
    resource_class = FundMunicipalityResource
admin.site.register(FundMunicipality, FundMunicipalityAdmin)



class FundONGResource(resources.ModelResource):
    class Meta:
        model = FundONG
class FundONGAdmin(ImportExportModelAdmin):
    resource_class = FundONGResource
admin.site.register(FundONG, FundONGAdmin)



class FundVolunteerResource(resources.ModelResource):
    class Meta:
        model = FundVolunteer
class FundVolunteerAdmin(ImportExportModelAdmin):
    resource_class = FundVolunteerResource
admin.site.register(FundVolunteer, FundVolunteerAdmin)









# Generated by Django 3.2.4 on 2022-01-08 21:05

from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('custom', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('custom_development', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Activity',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateField(null=True, verbose_name='Data Atividade')),
                ('name', models.CharField(blank=True, max_length=300, verbose_name='Naran Atividade')),
                ('place', models.CharField(blank=True, max_length=250, verbose_name='Fatin')),
                ('participation', models.CharField(max_length=255, null=True, verbose_name='Partisipasaun')),
                ('benefit', models.CharField(max_length=250, null=True, verbose_name='Benefísiu')),
                ('obs', models.TextField(verbose_name='OBS')),
                ('hashed', models.CharField(blank=True, max_length=50, null=True)),
                ('datetime', models.DateTimeField(auto_now_add=True, null=True)),
                ('administrativepost', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom.administrativepost')),
                ('municipality', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom.municipality')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Author')),
                ('village', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom.village')),
                ('year', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom.year', verbose_name='Tinan')),
            ],
            options={
                'verbose_name_plural': 'C.2. Livru Dadus Atividade Suku',
            },
        ),
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=300, null=True, verbose_name='Naran Projetu')),
                ('start_period', models.DateField(null=True, verbose_name='Data Hahu')),
                ('end_period', models.DateField(null=True, verbose_name='Data Remata')),
                ('benefit', models.CharField(max_length=200, null=True, verbose_name='Benefísiu')),
                ('obs', models.TextField(verbose_name='OBS')),
                ('hashed', models.CharField(blank=True, max_length=50, null=True)),
                ('datetime', models.DateTimeField(auto_now_add=True, null=True)),
                ('administrativepost', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom.administrativepost')),
                ('company', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='custom_development.company', verbose_name='Naran Kompañia')),
                ('municipality', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom.municipality')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Author')),
                ('village', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom.village')),
                ('year', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom.year', verbose_name='Tinan')),
            ],
            options={
                'verbose_name_plural': 'C.1. Livru Dadus Projetu Suku',
            },
        ),
        migrations.CreateModel(
            name='ImageProject',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.FileField(blank=True, null=True, upload_to='development/project/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['jpg', 'jpeg', 'png'])], verbose_name='Aneksu Imajen')),
                ('datetime', models.DateTimeField(null=True)),
                ('project', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='development.project', verbose_name='Naran Projetu')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'Aneksu Imajen Projetu',
            },
        ),
        migrations.CreateModel(
            name='ImageActivity',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.FileField(blank=True, null=True, upload_to='development/activity/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['jpg', 'jpeg', 'png'])], verbose_name='Aneksu Imajen')),
                ('datetime', models.DateTimeField(null=True)),
                ('activity', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='activityfiles', to='development.activity', verbose_name='Naran Atividade')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'Aneksu Imajen Atividade',
            },
        ),
        migrations.CreateModel(
            name='FundVolunteer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('volunteer', models.CharField(blank=True, max_length=200, null=True, verbose_name='Voluntáriu')),
                ('volunteer_material', models.CharField(blank=True, max_length=50, null=True, verbose_name='Ajuda Material')),
                ('volunteer_amount', models.DecimalField(blank=True, decimal_places=2, max_digits=11, null=True, verbose_name='Total Osan')),
                ('hashed', models.CharField(blank=True, max_length=50, null=True)),
                ('project', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='development.project', verbose_name='Naran Projetu')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Author')),
            ],
            options={
                'verbose_name_plural': 'Fundus Husi Voluntáriu',
            },
        ),
        migrations.CreateModel(
            name='FundONG',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ong_material', models.CharField(blank=True, max_length=50, null=True, verbose_name='Ajuda Material')),
                ('ong_amount', models.DecimalField(blank=True, decimal_places=2, max_digits=11, null=True, verbose_name='Total Osan')),
                ('hashed', models.CharField(blank=True, max_length=50, null=True)),
                ('ong', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom_development.ong', verbose_name='ONG')),
                ('project', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='development.project', verbose_name='Naran Projetu')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Author')),
            ],
            options={
                'verbose_name_plural': 'Fundus Husi ONG',
            },
        ),
        migrations.CreateModel(
            name='FundNational',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('national_material', models.CharField(blank=True, max_length=50, null=True, verbose_name='Ajuda Material')),
                ('national_amount', models.DecimalField(blank=True, decimal_places=2, max_digits=11, null=True, verbose_name='Total Osan')),
                ('hashed', models.CharField(blank=True, max_length=50, null=True)),
                ('activity', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='development.activity', verbose_name='Naran Atividade')),
                ('national', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom_development.national', verbose_name='Nasional')),
                ('project', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='development.project', verbose_name='Naran Projetu')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Author')),
            ],
            options={
                'verbose_name_plural': 'Fundus Husi Nasional',
            },
        ),
        migrations.CreateModel(
            name='FundMunicipality',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('municipality_material', models.CharField(blank=True, max_length=50, null=True, verbose_name='Ajuda Material')),
                ('municipality_amount', models.DecimalField(blank=True, decimal_places=2, max_digits=11, null=True, verbose_name='Total Osan')),
                ('hashed', models.CharField(blank=True, max_length=50, null=True)),
                ('activity', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='development.activity', verbose_name='Naran Atividade')),
                ('municipality', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom.municipality', verbose_name='Munisípiu')),
                ('project', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='development.project', verbose_name='Naran Projetu')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Author')),
            ],
            options={
                'verbose_name_plural': 'Fundus Husi Munisípiu',
            },
        ),
        migrations.CreateModel(
            name='FundCommunityContribute',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('community_contribute', models.CharField(blank=True, max_length=200, null=True, verbose_name='Kontribuisaun Komunidade')),
                ('communitycontribute_material', models.CharField(blank=True, max_length=50, null=True, verbose_name='Ajuda Material')),
                ('communitycontribute_amount', models.DecimalField(blank=True, decimal_places=2, max_digits=11, null=True, verbose_name='Total Osan')),
                ('hashed', models.CharField(blank=True, max_length=50, null=True)),
                ('activity', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='development.activity', verbose_name='Naran Atividade')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Author')),
            ],
            options={
                'verbose_name_plural': 'Fundus Husi Kontribuisaun Komunidade',
            },
        ),
        migrations.CreateModel(
            name='FundAgency',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('agency_material', models.CharField(blank=True, max_length=50, null=True, verbose_name='Ajuda Material')),
                ('agency_amount', models.DecimalField(blank=True, decimal_places=2, max_digits=11, null=True, verbose_name='Total Osan')),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('activity', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='development.activity', verbose_name='Naran Projetu')),
                ('agency', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='custom_development.agency', verbose_name='Ajénsia')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Author')),
            ],
            options={
                'verbose_name_plural': 'Fundus Husi Ajénsia',
            },
        ),
    ]



from django.shortcuts import render, redirect,get_object_or_404
from development.forms import ActivityForm, ImageActivityForm
from django.contrib import messages
from django.db.models import Q
from django.contrib.auth.decorators import login_required
from custom.utils import getnewid, getjustnewid, hash_md5, getlastid
from django.contrib.auth.decorators import login_required
from custom.models import *
from development.models import *
import numpy as np
from main.decorators import allowed_users
from employee.models import *

@login_required
def ActivityList(request):
    group = request.user.groups.all()[0].name
    try:
        empuser = EmployeeUser.objects.get(user = request.user)
        employee = Employee.objects.get(employeeuser=empuser)
    except:
        print('You are admin')
    activity = Activity.objects.filter(municipality=employee.municipality, administrativepost=employee.administrativepost, village=employee.village)
    context = {
        'title': 'Lista Atividade', 'activity1':"active",'group':group,
         'page':"view", 'objects':activity
    }
    return render(request, 'activity/list.html', context)

@login_required
@allowed_users(['sec', 'admin', 'xefe'])
def ActivityAdd(request):
    if request.method == 'POST':
        newid = getjustnewid(Activity)
        form = ActivityForm(request.POST, request.FILES)
        if form.is_valid():
            instance = form.save(commit=False)
            instance.id = newid
            instance.user = request.user
            user = get_object_or_404(EmployeeUser,user__id=request.user.id)
            instance.municipality = user.employee.municipality
            instance.administrativepost = user.employee.administrativepost
            instance.village = user.employee.village
            instance.save()
            # print(instance.hashed)
            messages.success(request, f'Susesu Kria Atividade' )
            return redirect('development:activity-add-fund', instance.hashed)
    else:
        form = ActivityForm()
    context = {'title':'Adisiona Atividade', 'activity1':"active",
     'page':"addactivity", 'form':form}
    return render(request, 'activity/add.html', context)

@login_required
@allowed_users(['sec', 'admin', 'xefe'])
def ImageActivityAdd(request, hashed):
    activity = get_object_or_404(Activity, hashed=hashed)
    if request.method == 'POST':
        newid = getjustnewid(Activity)
        images = request.FILES.getlist('image')
        form = ImageActivityForm(request.POST, request.FILES)
        if form.is_valid():
            for image in images:
                files = ImageActivity(activity_id=activity.id, image=image, user=request.user)
                files.save()
            messages.success(request, f'Susesu Kria Aneksu Imajen!' )
            return redirect('development:activity-detail', activity.hashed)
    else:
        form = ImageActivityForm()
    context = {'title':'Aneksu Imajen ba Atividade %s' % (activity.name), 'activity1':"active",
     'page':"addactivity", 'form':form}
    return render(request, 'activity/add1.html', context)

@login_required
@allowed_users('sec')
def ActivityEdit(request, hashed):
    group = request.user.groups.all()[0].name
    activity = Activity.objects.get(hashed=hashed)

    form = ActivityForm(instance=activity)
    if request.method == 'POST':
        form = ActivityForm(request.POST, instance=activity)
        if form.is_valid():
            form.save()
            messages.success(request, f'Susesu Altera Atividade' )
            return redirect('development:activity-list')

    context = {'title':'Altera Atividade', 'activity1':"active", 'group': group,
     'form':form}
    return render(request, 'activity/add.html', context)

@login_required
def ActivityDetail(request, hashed):
    group = request.user.groups.all()[0].name
    objects = Activity.objects.get(hashed=hashed)
    imageactivity = ImageActivity.objects.filter(activity=objects)
    fundNational = FundNational.objects.filter(activity=objects)
    fundMunicipality = FundMunicipality.objects.filter(activity=objects)
    fundContribute = FundCommunityContribute.objects.filter(activity=objects)
    fundAgency = FundAgency.objects.filter(activity=objects)
    data = []
    for i in fundNational:
        data.append({'fund': 'Nasional', 'name': i, 'hashed': i.hashed, 'amount': i.national_amount, 'material': i.national_material})
    for j in fundMunicipality:
        data.append({'fund': 'Municipio', 'name': j, 'hashed': j.hashed, 'amount': j.municipality_amount, 'material': j.municipality_material})
    for k in fundContribute:
        data.append({'fund': 'Kontribuisaun Komunidade', 'name': k, 'hashed': k.hashed, 'amount': k.communitycontribute_amount, 'material': k.communitycontribute_material})
    for l in fundAgency:
        data.append({'fund': 'Ajensia', 'name': l, 'hashed': l.hashed, 'amount': l.agency_amount, 'material': l.agency_material})
    result = np.array(data)
    total = []
    for r  in result:
        total.append(r['amount'])
    total_amount = np.sum(total)
    context =  {
		'objects':objects,'title': 'Detalla Atividade', 'group':group,
		'result': result, 'total': total_amount, 'activity1':"active",'imageactivity':imageactivity
	}
    return render(request, 'activity/detail.html', context)

@login_required
@allowed_users(allowed_roles=['sec', 'xefe'])
def DeleteActivity(request, hashed):
    activity = get_object_or_404(Activity,hashed=hashed)
    activity.delete()
    messages.success(request, f'Dadus Atividade {activity.name} Hamoos ho Susesu.')
    return redirect('development:activity-list')



import datetime
from django.http import request
from django.shortcuts import get_object_or_404, redirect, render
from custom_development.models import *
from development.forms import AgencyForm, NationalForm, OngForm, CompanyForm
from django.contrib import messages
from custom.utils import getjustnewid
from django.contrib.auth.decorators import login_required
from custom.models import *
from development.models import *
from main.decorators import allowed_users


@login_required
def CustomNationalList(request):
    group = request.user.groups.all()[0].name
    fields = ['Nu.', 'Naran', 'Code', 'Asaun']
    objects = National.objects.all()
    context = {
        'title': 'Lista Dadus Custom Nasional',
        'objects': objects, 'group':group,
        'fields': fields, 'nationalactive':"active"
    }
    return render(request, 'custom/national_list.html', context)


@login_required
@allowed_users(['sec', 'admin', 'xefe'])
def CustomNationalAdd(request):
    if request.method == 'POST':
        newid = getjustnewid(National)
        form = NationalForm(request.POST)
        if form.is_valid():
            instance = form.save(commit=False)
            instance.id = newid
            instance.save()
            messages.success(request, f'Susesu Kria Nasional' )
            return redirect('development:custom-national-lists')
    else: 
        form = NationalForm()
    context = {
        'title': 'Aumenta Dadus Custom Nasional',
        'form': form, 'nationalactive':"active"
    }
    return render(request, 'custom/national_form.html', context)

@login_required
@allowed_users(['sec', 'admin'])
def CustomNationalUpdate(request, pk):
    objects = get_object_or_404(National, id=pk)
    if request.method == 'POST':
        form = NationalForm(request.POST, instance=objects)
        if form.is_valid():
            form.save()
            messages.success(request, f'Susesu Altera Nasional' )
            return redirect('development:custom-national-lists')
    else:
        form = NationalForm(instance=objects)
    context = {
        'title': 'Altera Dadus Custom Nasional',
        'form': form, 'nationalactive':"active"
    }
    return render(request, 'custom/national_form.html', context)


@login_required
def CustomONGList(request):
    group = request.user.groups.all()[0].name
    objects = ONG.objects.all()
    fields = ['Nu.', 'Naran', 'Asaun']
    
    # field_names = list(model._meta.get_fields())
    # titles = [f.verbose_name for f in field_names]
    context = {
        'title': 'Lista Dadus Custom ONG',
        'objects': objects, 'group': group,
        'fields': fields,'ongactive':"active"
    }
    return render(request, 'custom/ong_list.html', context)


@login_required
@allowed_users(['sec', 'admin', 'xefe'])
def CustomONGAdd(request):
    if request.method == 'POST':
        newid = getjustnewid(ONG)
        form = OngForm(request.POST)
        if form.is_valid():
            instance = form.save(commit=False)
            instance.id = newid
            instance.save()
            messages.success(request, f'Susesu Kria ONG' )
            return redirect('development:custom-ong-lists')
    else: 
        form = OngForm()
    context = {
        'title': 'Aumenta Dadus Custom ONG',
        'form': form, 'ongactive':"active"
    }
    return render(request, 'custom/ong_form.html', context)

@login_required
@allowed_users(['sec', 'admin'])
def CustomONGUpdate(request, pk):
    objects = get_object_or_404(ONG, id=pk)
    if request.method == 'POST':
        form = OngForm(request.POST, instance=objects)
        if form.is_valid():
            form.save()
            messages.success(request, f'Susesu Altera ONG' )
            return redirect('development:custom-ong-lists')
    else:
        form = OngForm(instance=objects)
    context = {
        'title': 'Altera Dadus Custom ONG',
        'form': form,'ongactive':"active"
    }
    return render(request, 'custom/ong_form.html', context)


@login_required
def CustomAgencyList(request):
    group = request.user.groups.all()[0].name
    objects = Agency.objects.all()
    fields = ['Nu.', 'Naran', 'Asaun']
    
    # field_names = list(model._meta.get_fields())
    # titles = [f.verbose_name for f in field_names]
    context = {
        'title': 'Lista Dadus Custom Ajénsia',
        'objects': objects, 'group': group,
        'fields': fields,'agencyactive':"active"
    }
    return render(request, 'custom/agency_list.html', context)


@login_required
@allowed_users(['sec', 'admin', 'xefe'])
def CustomAgencyAdd(request):
    if request.method == 'POST':
        newid = getjustnewid(Agency)
        form = AgencyForm(request.POST)
        if form.is_valid():
            instance = form.save(commit=False)
            instance.id = newid
            instance.save()
            messages.success(request, f'Susesu Kria Ajénsia' )
            return redirect('development:custom-agency-lists')
    else: 
        form = AgencyForm()
    context = {
        'title': 'Aumenta Dadus Custom Ajénsia',
        'form': form,'agencyactive':"active"
    }
    return render(request, 'custom/agency_form.html', context)

@login_required
@allowed_users(['sec', 'admin'])
def CustomAgencypdate(request, pk):
    objects = get_object_or_404(Agency, id=pk)
    if request.method == 'POST':
        form = AgencyForm(request.POST, instance=objects)
        if form.is_valid():
            form.save()
            messages.success(request, f'Susesu Altera Ajénsia' )
            return redirect('development:custom-agency-lists')
    else:
        form = AgencyForm(instance=objects)
    context = {
        'title': 'Altera Dadus Custom Ajénsia',
        'form': form, 'agencyactive':"active"
    }
    return render(request, 'custom/agency_form.html', context)


@login_required
def CustomCompanyList(request):
    group = request.user.groups.all()[0].name
    company = Company.objects.all()
    fields = ['Nu.', 'Naran', 'Asaun']
    context = {'title':'Lista Dadus Custom Kompañia','objects':company, 'group': group,
    'fields':fields,'companyactive':"active"}
    return render(request, 'custom/company_list.html', context)

@login_required
@allowed_users(['sec', 'admin', 'xefe'])
def CustomCompanyAdd(request):
    if request.method == 'POST':
        form = CompanyForm(request.POST)
        if form.is_valid():
            instance = form.save(commit=False)
            instance.save()
            messages.success(request, f'Susesu Kria Kompañia')
            return redirect('development:custom-company-lists')
    else: 
        form = CompanyForm()
    context = {
        'title': 'Aumenta Dadus Custom Kompañia',
        'form': form,'companyactive':"active"
    }
    return render(request, 'custom/company_form.html', context)

@login_required
@allowed_users(['sec', 'admin'])
def CustomCompanyUpdate(request, pk):
    objects = get_object_or_404(Company, id=pk)
    if request.method == 'POST':
        form = CompanyForm(request.POST, instance=objects)
        if form.is_valid():
            form.save()
            messages.success(request, f'Susesu Altera Kompañia' )
            return redirect('development:custom-company-lists')
    else:
        form = CompanyForm(instance=objects)
    context = {
        'title': 'Altera Dadus Custom Kompañia',
        'form': form,'companyactive':"active"
    }
    return render(request, 'custom/company_form.html', context)

@login_required
def load_postu(request):
    id_municipality = request.GET.get('municipality')
    post = AdministrativePost.objects.filter(municipality=id_municipality).order_by('id')
    context = {'post':post,'load_ajax':'post'}

    return render(request, 'custom/dependent_select.html',context)

@login_required
def load_suku(request):
    id_post = request.GET.get('post')
    village = Village.objects.filter(post=id_post).order_by('id')
    context = {'village':village,'load_ajax':'village'}

    return render(request, 'custom/dependent_select.html',context)






from django.urls import path
from . import views
app_name = 'development'

urlpatterns =[
	path('', views.DevelopmentDashboard, name='dashboard-development'),
	path('load-postu/', views.load_postu, name='ajax_load_postu'),
    path('load-suku/', views.load_suku, name='ajax_load_suku'),

    # Projects
	path('project/list/', views.ProjectList, name='project-list'),
	path('project/add/', views.ProjectAdd, name='project-add'),
	path('project/edit/<str:hashed>/', views.ProjectEdit, name='project-edit'),
	path('project/viewdetail/<str:hashed>/', views.ProjectDetail, name='project-viewdetail'),
	path('project/add/image/<str:hashed>/', views.ImageProjectAdd, name='project-add-image'),
	path('project/delete/<str:hashed>/', views.DeleteProject, name='project-delete'),

	
	# Fundus Project
	path('project/add/fund/<str:hashed>/', views.FundProjectAdd, name='project-add-fund'),
	path('project/add1/fund1/<str:hashed>/', views.FundProjectAdd1, name='project-add1-fund1'),
	path('project/fundnational/list/', views.FundNationalList, name='fundnational-project-list'),
	path('project/fundnational/edit/<str:hashed>/', views.FundNationalEdit, name='fundnational-project-edit'),
	path('project/fundmunicipality/list/', views.FundMunicipalityList, name='fundmunicipality-project-list'),
	path('project/fundmunicipality/edit/<str:hashed>/', views.FundMunicipalityEdit, name='fundmunicipality-project-edit'),
	path('project/fundong/list/', views.FundONGList, name='fundong-project-list'),
	path('project/fundong/edit/<str:hashed>/', views.FundONGEdit, name='fundong-project-edit'),
	path('project/fundavolunteer/edit/<str:hashed>/', views.FundVolunteerEdit, name='fundvolunteer-project-edit'),

	# REPORTS
	path('report/list/', views.ReportList, name='report-list'),


	#Chart
	path('project-charts/', views.project_charts, name="project-charts"),
	path('activity-charts/', views.activity_charts, name="activity-charts"),

	# Activities
	path('activity/list/', views.ActivityList, name='activity-list'),
	path('activity/add/', views.ActivityAdd, name='activity-add'),
	path('activity/edit/<str:hashed>/', views.ActivityEdit, name='activity-edit'),
	path('activity/viewdetail/<str:hashed>/', views.ActivityDetail, name='activity-detail'),
	path('activity/add/image/<str:hashed>/', views.ImageActivityAdd, name='activity-add-image'),
	path('activity/delete/<str:hashed>/', views.DeleteActivity, name='activity-delete'),

	# Fundus Activities
	path('activity/add/fund/<str:hashed>/', views.FundActivityAdd, name='activity-add-fund'),
	path('activity/add1/fund1/<str:hashed>/', views.FundActivityAdd1, name='activity-add1-fund1'),
	path('activity/fundagency/list/', views.FundAgencyList, name='fundagency-activity-list'),
	path('activity/fundagency/edit/<str:hashed>/', views.FundAgencyEdit, name='fundagency-activity-edit'),
	path('activity/fundcommunity/edit/<str:hashed>/', views.FundCommunityContributeEdit, name='fundcommunity-activity-edit'),


	# CUSTOM NASIONAL
	path('custom/national/list/', views.CustomNationalList, name='custom-national-lists'),
	path('custom/national/add/', views.CustomNationalAdd, name='custom-national-add'),
	path('custom/national/update/<str:pk>', views.CustomNationalUpdate, name='custom-national-update'),

	# CUSTOM ONG
	path('custom/ong/list/', views.CustomONGList, name='custom-ong-lists'),
	path('custom/ong/add/', views.CustomONGAdd, name='custom-ong-add'),
	path('custom/ong/update/<str:pk>', views.CustomONGUpdate, name='custom-ong-update'),

	# CUSTOM AJENSIA
	path('custom/agency/list/', views.CustomAgencyList, name='custom-agency-lists'),
	path('custom/agency/add/', views.CustomAgencyAdd, name='custom-agency-add'),
	path('custom/agency/update/<str:pk>', views.CustomAgencypdate, name='custom-agency-update'),

	# CUSTOM KOMPANIA
	path('custom/company/list/', views.CustomCompanyList, name='custom-company-lists'),
	path('custom/company/add/', views.CustomCompanyAdd, name='custom-company-add'),
	path('custom/company/update/<str:pk>/', views.CustomCompanyUpdate, name='custom-company-update'),

]